==> mdpws-model-1.0.0-sources.jar: org/somda/sdc/mdpws/model/StreamTypeType.java <==

package org.somda.sdc.mdpws.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlID;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.CopyStrategy2;
import org.jvnet.jaxb2_commons.lang.CopyTo2;
import org.jvnet.jaxb2_commons.lang.JAXBCopyStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.w3c.dom.Element;


/**
 * Element to describes a specific stream type.
 * 
 * <p>Java class for StreamTypeType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StreamTypeType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="StreamTransmission" type="{http://standards.ieee.org/downloads/11073/11073-20702-2016}StreamTransmissionType"/&gt;
 *         &lt;any processContents='skip' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="Id" use="required" type="{http://www.w3.org/2001/XMLSchema}ID" /&gt;
 *       &lt;attribute name="StreamType" use="required" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;attribute name="Element" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;attribute name="ActionUri" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;anyAttribute processContents='skip' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StreamTypeType", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", propOrder = {
    "streamTransmission",
    "any"
})
public class StreamTypeType implements Cloneable, CopyTo2, ToString2
{

    @XmlElement(name = "StreamTransmission", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", required = true)
    protected StreamTransmissionType streamTransmission;
    @XmlAnyElement
    protected List<Element> any;
    @XmlAttribute(name = "Id", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "StreamType", required = true)
    @XmlSchemaType(name = "anyURI")
    protected String streamType;
    @XmlAttribute(name = "Element")
    @XmlSchemaType(name = "anyURI")
    protected String element;
    @XmlAttribute(name = "ActionUri")
    @XmlSchemaType(name = "anyURI")
    protected String actionUri;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the streamTransmission property.
     * 
     * @return
     *     possible object is
     *     {@link StreamTransmissionType }
     *     
     */
    public StreamTransmissionType getStreamTransmission() {
        return streamTransmission;
    }

    /**
     * Sets the value of the streamTransmission property.
     * 
     * @param value
     *     allowed object is
     *     {@link StreamTransmissionType }
     *     
     */
    public void setStreamTransmission(StreamTransmissionType value) {
        this.streamTransmission = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * 
     * 
     */
    public List<Element> getAny() {
        if (any == null) {
            any = new ArrayList<Element>();
        }
        return this.any;
    }

    /**
     * Gets the value of the id property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Gets the value of the streamType property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getStreamType() {
        return streamType;
    }

    /**
     * Sets the value of the streamType property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStreamType(String value) {
        this.streamType = value;
    }

    /**
     * Gets the value of the element property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getElement() {
        return element;
    }

    /**
     * Sets the value of the element property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setElement(String value) {
        this.element = value;
    }

    /**
     * Gets the value of the actionUri property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getActionUri() {
        return actionUri;
    }

    /**
     * Sets the value of the actionUri property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setActionUri(String value) {
        this.actionUri = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setAny(List<Element> value) {
        this.any = null;
        if (value!= null) {
            List<Element> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public Object clone() {
        return copyTo(createNewInstance());
    }

    public Object copyTo(Object target) {
        final CopyStrategy2 strategy = JAXBCopyStrategy.INSTANCE;
        return copyTo(null, target, strategy);
    }

    public Object copyTo(ObjectLocator locator, Object target, CopyStrategy2 strategy) {
        final Object draftCopy = ((target == null)?createNewInstance():target);
        if (draftCopy instanceof StreamTypeType) {
            final StreamTypeType copy = ((StreamTypeType) draftCopy);
            {
                Boolean streamTransmissionShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.streamTransmission!= null));
                if (streamTransmissionShouldBeCopiedAndSet == Boolean.TRUE) {
                    StreamTransmissionType sourceStreamTransmission;
                    sourceStreamTransmission = this.getStreamTransmission();
                    StreamTransmissionType copyStreamTransmission = ((StreamTransmissionType) strategy.copy(LocatorUtils.property(locator, "streamTransmission", sourceStreamTransmission), sourceStreamTransmission, (this.streamTransmission!= null)));
                    copy.setStreamTransmission(copyStreamTransmission);
                } else {
                    if (streamTransmissionShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.streamTransmission = null;
                    }
                }
            }
            {
                Boolean anyShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, ((this.any!= null)&&(!this.any.isEmpty())));
                if (anyShouldBeCopiedAndSet == Boolean.TRUE) {
                    List<Element> sourceAny;
                    sourceAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
                    @SuppressWarnings("unchecked")
                    List<Element> copyAny = ((List<Element> ) strategy.copy(LocatorUtils.property(locator, "any", sourceAny), sourceAny, ((this.any!= null)&&(!this.any.isEmpty()))));
                    copy.setAny(copyAny);
                } else {
                    if (anyShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.any = null;
                    }
                }
            }
            {
                Boolean idShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.id!= null));
                if (idShouldBeCopiedAndSet == Boolean.TRUE) {
                    String sourceId;
                    sourceId = this.getId();
                    String copyId = ((String) strategy.copy(LocatorUtils.property(locator, "id", sourceId), sourceId, (this.id!= null)));
                    copy.setId(copyId);
                } else {
                    if (idShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.id = null;
                    }
                }
            }
            {
                Boolean streamTypeShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.streamType!= null));
                if (streamTypeShouldBeCopiedAndSet == Boolean.TRUE) {
                    String sourceStreamType;
                    sourceStreamType = this.getStreamType();
                    String copyStreamType = ((String) strategy.copy(LocatorUtils.property(locator, "streamType", sourceStreamType), sourceStreamType, (this.streamType!= null)));
                    copy.setStreamType(copyStreamType);
                } else {
                    if (streamTypeShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.streamType = null;
                    }
                }
            }
            {
                Boolean elementShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.element!= null));
                if (elementShouldBeCopiedAndSet == Boolean.TRUE) {
                    String sourceElement;
                    sourceElement = this.getElement();
                    String copyElement = ((String) strategy.copy(LocatorUtils.property(locator, "element", sourceElement), sourceElement, (this.element!= null)));
                    copy.setElement(copyElement);
                } else {
                    if (elementShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.element = null;
                    }
                }
            }
            {
                Boolean actionUriShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.actionUri!= null));
                if (actionUriShouldBeCopiedAndSet == Boolean.TRUE) {
                    String sourceActionUri;
                    sourceActionUri = this.getActionUri();
                    String copyActionUri = ((String) strategy.copy(LocatorUtils.property(locator, "actionUri", sourceActionUri), sourceActionUri, (this.actionUri!= null)));
                    copy.setActionUri(copyActionUri);
                } else {
                    if (actionUriShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.actionUri = null;
                    }
                }
            }
        }
        return draftCopy;
    }

    public Object createNewInstance() {
        return new StreamTypeType();
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            StreamTransmissionType theStreamTransmission;
            theStreamTransmission = this.getStreamTransmission();
            strategy.appendField(locator, this, "streamTransmission", buffer, theStreamTransmission, (this.streamTransmission!= null));
        }
        {
            List<Element> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        {
            String theId;
            theId = this.getId();
            strategy.appendField(locator, this, "id", buffer, theId, (this.id!= null));
        }
        {
            String theStreamType;
            theStreamType = this.getStreamType();
            strategy.appendField(locator, this, "streamType", buffer, theStreamType, (this.streamType!= null));
        }
        {
            String theElement;
            theElement = this.getElement();
            strategy.appendField(locator, this, "element", buffer, theElement, (this.element!= null));
        }
        {
            String theActionUri;
            theActionUri = this.getActionUri();
            strategy.appendField(locator, this, "actionUri", buffer, theActionUri, (this.actionUri!= null));
        }
        return buffer;
    }

}

==> mdpws-model-1.0.1-sources.jar: org/somda/sdc/mdpws/model/StreamTypeType.java <==

package org.somda.sdc.mdpws.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlID;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.CopyStrategy2;
import org.jvnet.jaxb2_commons.lang.CopyTo2;
import org.jvnet.jaxb2_commons.lang.JAXBCopyStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.w3c.dom.Element;


/**
 * Element to describes a specific stream type.
 * 
 * <p>Java class for StreamTypeType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StreamTypeType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="StreamTransmission" type="{http://standards.ieee.org/downloads/11073/11073-20702-2016}StreamTransmissionType"/&gt;
 *         &lt;any processContents='skip' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="Id" use="required" type="{http://www.w3.org/2001/XMLSchema}ID" /&gt;
 *       &lt;attribute name="StreamType" use="required" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;attribute name="Element" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;attribute name="ActionUri" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;anyAttribute processContents='skip' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StreamTypeType", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", propOrder = {
    "streamTransmission",
    "any"
})
public class StreamTypeType implements Cloneable, CopyTo2, ToString2
{

    @XmlElement(name = "StreamTransmission", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", required = true)
    protected StreamTransmissionType streamTransmission;
    @XmlAnyElement
    protected List<Element> any;
    @XmlAttribute(name = "Id", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "StreamType", required = true)
    @XmlSchemaType(name = "anyURI")
    protected String streamType;
    @XmlAttribute(name = "Element")
    @XmlSchemaType(name = "anyURI")
    protected String element;
    @XmlAttribute(name = "ActionUri")
    @XmlSchemaType(name = "anyURI")
    protected String actionUri;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Ruft den Wert der streamTransmission-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link StreamTransmissionType }
     *     
     */
    public StreamTransmissionType getStreamTransmission() {
        return streamTransmission;
    }

    /**
     * Legt den Wert der streamTransmission-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link StreamTransmissionType }
     *     
     */
    public void setStreamTransmission(StreamTransmissionType value) {
        this.streamTransmission = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * 
     * 
     */
    public List<Element> getAny() {
        if (any == null) {
            any = new ArrayList<Element>();
        }
        return this.any;
    }

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der streamType-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getStreamType() {
        return streamType;
    }

    /**
     * Legt den Wert der streamType-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStreamType(String value) {
        this.streamType = value;
    }

    /**
     * Ruft den Wert der element-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getElement() {
        return element;
    }

    /**
     * Legt den Wert der element-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setElement(String value) {
        this.element = value;
    }

    /**
     * Ruft den Wert der actionUri-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getActionUri() {
        return actionUri;
    }

    /**
     * Legt den Wert der actionUri-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setActionUri(String value) {
        this.actionUri = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setAny(List<Element> value) {
        this.any = null;
        if (value!= null) {
            List<Element> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public Object clone() {
        return copyTo(createNewInstance());
    }

    public Object copyTo(Object target) {
        final CopyStrategy2 strategy = JAXBCopyStrategy.INSTANCE;
        return copyTo(null, target, strategy);
    }

    public Object copyTo(ObjectLocator locator, Object target, CopyStrategy2 strategy) {
        final Object draftCopy = ((target == null)?createNewInstance():target);
        if (draftCopy instanceof StreamTypeType) {
            final StreamTypeType copy = ((StreamTypeType) draftCopy);
            {
                Boolean streamTransmissionShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.streamTransmission!= null));
                if (streamTransmissionShouldBeCopiedAndSet == Boolean.TRUE) {
                    StreamTransmissionType sourceStreamTransmission;
                    sourceStreamTransmission = this.getStreamTransmission();
                    StreamTransmissionType copyStreamTransmission = ((StreamTransmissionType) strategy.copy(LocatorUtils.property(locator, "streamTransmission", sourceStreamTransmission), sourceStreamTransmission, (this.streamTransmission!= null)));
                    copy.setStreamTransmission(copyStreamTransmission);
                } else {
                    if (streamTransmissionShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.streamTransmission = null;
                    }
                }
            }
            {
                Boolean anyShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, ((this.any!= null)&&(!this.any.isEmpty())));
                if (anyShouldBeCopiedAndSet == Boolean.TRUE) {
                    List<Element> sourceAny;
                    sourceAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
                    @SuppressWarnings("unchecked")
                    List<Element> copyAny = ((List<Element> ) strategy.copy(LocatorUtils.property(locator, "any", sourceAny), sourceAny, ((this.any!= null)&&(!this.any.isEmpty()))));
                    copy.setAny(copyAny);
                } else {
                    if (anyShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.any = null;
                    }
                }
            }
            {
                Boolean idShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.id!= null));
                if (idShouldBeCopiedAndSet == Boolean.TRUE) {
                    String sourceId;
                    sourceId = this.getId();
                    String copyId = ((String) strategy.copy(LocatorUtils.property(locator, "id", sourceId), sourceId, (this.id!= null)));
                    copy.setId(copyId);
                } else {
                    if (idShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.id = null;
                    }
                }
            }
            {
                Boolean streamTypeShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.streamType!= null));
                if (streamTypeShouldBeCopiedAndSet == Boolean.TRUE) {
                    String sourceStreamType;
                    sourceStreamType = this.getStreamType();
                    String copyStreamType = ((String) strategy.copy(LocatorUtils.property(locator, "streamType", sourceStreamType), sourceStreamType, (this.streamType!= null)));
                    copy.setStreamType(copyStreamType);
                } else {
                    if (streamTypeShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.streamType = null;
                    }
                }
            }
            {
                Boolean elementShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.element!= null));
                if (elementShouldBeCopiedAndSet == Boolean.TRUE) {
                    String sourceElement;
                    sourceElement = this.getElement();
                    String copyElement = ((String) strategy.copy(LocatorUtils.property(locator, "element", sourceElement), sourceElement, (this.element!= null)));
                    copy.setElement(copyElement);
                } else {
                    if (elementShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.element = null;
                    }
                }
            }
            {
                Boolean actionUriShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.actionUri!= null));
                if (actionUriShouldBeCopiedAndSet == Boolean.TRUE) {
                    String sourceActionUri;
                    sourceActionUri = this.getActionUri();
                    String copyActionUri = ((String) strategy.copy(LocatorUtils.property(locator, "actionUri", sourceActionUri), sourceActionUri, (this.actionUri!= null)));
                    copy.setActionUri(copyActionUri);
                } else {
                    if (actionUriShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.actionUri = null;
                    }
                }
            }
        }
        return draftCopy;
    }

    public Object createNewInstance() {
        return new StreamTypeType();
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            StreamTransmissionType theStreamTransmission;
            theStreamTransmission = this.getStreamTransmission();
            strategy.appendField(locator, this, "streamTransmission", buffer, theStreamTransmission, (this.streamTransmission!= null));
        }
        {
            List<Element> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        {
            String theId;
            theId = this.getId();
            strategy.appendField(locator, this, "id", buffer, theId, (this.id!= null));
        }
        {
            String theStreamType;
            theStreamType = this.getStreamType();
            strategy.appendField(locator, this, "streamType", buffer, theStreamType, (this.streamType!= null));
        }
        {
            String theElement;
            theElement = this.getElement();
            strategy.appendField(locator, this, "element", buffer, theElement, (this.element!= null));
        }
        {
            String theActionUri;
            theActionUri = this.getActionUri();
            strategy.appendField(locator, this, "actionUri", buffer, theActionUri, (this.actionUri!= null));
        }
        return buffer;
    }

}
